==> ParUtils-1.0.4-py3-none-any.whl: parutils/file.py <==
import os
import os.path as p
from shutil import rmtree

from .string import like_list


def delete_folder(dir):
    """Deletes a folder and its content"""
    from parutils.logging.main import log

    if p.exists(dir):
        rmtree(dir)
        log(f"Folder '{dir}' deleted")


def mkdirs(dir, delete=False):
    """Same as os.makedirs but
    - Input can also be a path
    - With a 'delete' option which (if True) deletes the folder if it already exists."""
    from parutils.logging.main import log

    if not dir:
        return

    if p.exists(dir) and not delete:
        return
    if p.exists(dir) and delete:
        delete_folder(dir)
    os.makedirs(dir)
    log(f"Folder '{dir}' created")


def list_files(in_dir,
               walk=False,
               file_names_only=False,
               abspath=False,
               only_list=[],
               ignore_list=[]):
    """Lists the files of the 'in_dir' directory

    - incl_root: if True, the root directory is included in each paths
    - walk: if True, the files of all the subdirectories are listed as well
    - only_list: list of wanted patterns. e.g. ['*.py'] (only these patterns will be output)
    - ignore_list: list of unwanted patterns. e.g. ['*.pyc'] (these patterns won't be output)
    """

    if not p.exists(in_dir):
        return []

    out = []
    for root, dir, files in os.walk(in_dir):
        for file in files:
            cur_path = file if file_names_only else p.join(root, file)
            cur_path = p.abspath(cur_path) if abspath else cur_path
            cur_path = cur_path.replace('\\', '/')
            only = not only_list or like_list(file, only_list, case_sensitive=False)
            ignore = not like_list(file, ignore_list, case_sensitive=False)
            if only and ignore:
                out.append(cur_path)
        if not walk:
            break

    out.sort()
    return out


def load_txt(in_path, list_out=True):
    """Loads a text file

    - list_out: if True, a list es output, each element representing a line a the file. If False, a string is output.
    """

    if list_out:
        out = []
    else:
        out = ''

    with open(in_path, 'r', encoding='utf-8') as in_file:
        for line in in_file:
            if list_out:
                out.append(line.strip('\n'))
            else:
                out += line

    return out


def save_list(in_list, out_path, att='w'):
    """Saves a list in a file, each element representing a line"""

    mkdirs(p.dirname(out_path))
    with open(out_path, 'w', encoding='utf-8') as out_file:
        for i, elt in enumerate(in_list):
            s = str(elt).strip("\n")
            if i == 0:
                out_file.write(s)
            else:
                out_file.write('\n' + s)


def count_lines(in_path):
    """Counts the number of lines of a file"""

    with open(in_path, 'r', encoding='utf-8') as in_file:
        i = 0
        for line in in_file:
            i += 1

    return i

==> ParUtils-1.0.6-py3-none-any.whl: parutils/file.py <==
import os
import os.path as p
from shutil import rmtree

from .string import like_list


def delete_folder(dir):
    """Deletes a folder and its content"""
    from parutils.logging.main import log

    if p.exists(dir):
        rmtree(dir)
        log(f"Folder '{dir}' deleted")


def mkdirs(dir, delete=False):
    """Same as os.makedirs but
    - Input can also be a path
    - With a 'delete' option which (if True) deletes the folder if it already exists."""
    from parutils.logging.main import log

    if not dir:
        return

    if p.exists(dir) and not delete:
        return
    if p.exists(dir) and delete:
        delete_folder(dir)
    os.makedirs(dir)
    log(f"Folder '{dir}' created")


def list_files(in_dir,
               walk=False,
               incl_root=False,
               abspath=False,
               only_list=[],
               ignore_list=[]):
    """Lists the files of the 'in_dir' directory

    - incl_root: if True, the root directory is included in each paths
    - walk: if True, the files of all the subdirectories are listed as well
    - only_list: list of wanted patterns. e.g. ['*.py'] (only these patterns will be output)
    - ignore_list: list of unwanted patterns. e.g. ['*.pyc'] (these patterns won't be output)
    """

    if not p.exists(in_dir):
        return []

    out = []
    for root, dir, files in os.walk(in_dir):
        for file in files:
            cur_path = file if not incl_root else p.join(root, file)
            cur_path = p.abspath(cur_path) if abspath else cur_path
            cur_path = cur_path.replace('\\', '/')
            only = not only_list or like_list(file, only_list, case_sensitive=False)
            ignore = not like_list(file, ignore_list, case_sensitive=False)
            if only and ignore:
                out.append(cur_path)
        if not walk:
            break

    out.sort()
    return out


def load_txt(in_path, list_out=True):
    """Loads a text file

    - list_out: if True, a list es output, each element representing a line a the file. If False, a string is output.
    """

    if list_out:
        out = []
    else:
        out = ''

    with open(in_path, 'r', encoding='utf-8') as in_file:
        for line in in_file:
            if list_out:
                out.append(line.strip('\n'))
            else:
                out += line

    return out


def save_list(in_list, out_path, att='w'):
    """Saves a list in a file, each element representing a line"""

    mkdirs(p.dirname(out_path))
    with open(out_path, 'w', encoding='utf-8') as out_file:
        for i, elt in enumerate(in_list):
            s = str(elt).strip("\n")
            if i == 0:
                out_file.write(s)
            else:
                out_file.write('\n' + s)


def count_lines(in_path):
    """Counts the number of lines of a file"""

    with open(in_path, 'r', encoding='utf-8') as in_file:
        i = 0
        for line in in_file:
            i += 1

    return i
